bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.get_mask
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.get_mask